<?php
/**
 * @file
 * This file Contain brightcove service callbacks to upload,retrive
 * and create videos file to brightcove media server.
 */
function _brightcove_resource_retrieve($vid) {
  $vid = (double) $vid;
  $video = brightcove_video_load($vid);
  if (!empty($video)) {
    return $video;
  }
  return services_error('Video vid '. $vid .' not found', 404);
}

function _brightcove_resource_create($file, $video_meta) {
  $file = (object) $file;

  if (!isset($file->file)) {
    return FALSE;
  }

  $update = array();
  if (!empty($file->fid)) {
    $update = 'fid';
  }

  $dir = dirname($file->filepath);

  if (!file_check_directory($dir, FILE_CREATE_DIRECTORY)) {
    return services_error("Could not create destination directory for file.");
  }

  $file->filepath = file_destination(file_create_path($file->filepath), FILE_EXISTS_RENAME);

  if ((!isset($file->filename)) || (empty($file->filename))) {
    $file->filename = trim(basename($file->filepath), '.');
  }

  $file->filename = file_munge_filename($file->filename, $extensions, TRUE);
  $file->filemime = file_get_mimetype($file->filename);

  if (preg_match('/\.(php|pl|py|cgi|asp|js)$/i', $file->filename) && (drupal_substr($file->filename, -4) != '.txt')) {
    $file->filemime = 'text/plain';
    $file->filepath .= '.txt';
    $file->filename .= '.txt';
  }

  if (empty($file->filepath) || file_check_path($file->filepath) === FALSE) {
    return services_error("Destintion directory does not exist or is not writeable.");
  }

  $file->filepath .= '/'. $file->filename;

  if (!file_save_data(base64_decode($file->file), $file->filepath)) {
    return services_error("Could not write file to destination");
  }

  drupal_write_record('files', $file, $update);

  if (empty($update)) {
    foreach (module_implements('file_insert') as $module) {
      $function =  $module .'_file_insert';
      $function($file);
    }
  }

  $file->file = "";
  if (!empty($user->uid)) {
    $file->uid = $user->uid;
  }
  else {
    $file->uid = 1;
  }

  $read_token = variable_get('brightcove_read_api_key', '');
  $write_token = variable_get('brightcove_write_api_key', '');

  if (empty($read_token)) {
    drupal_set_message(t('Cannot initialize Brightcove API. Contact site administrators.'), 'error');
    watchdog('brightcove', 'Brightcove Read API keys not found, cannot initialize Echove SDK.', array(), WATCHDOG_ERROR);
  }
  else {
    $meta = array(
      'name' => $video_meta->title,
      'shortDescription' => 'test',
      'longDescription' => 'test',
      'linkText' => '',
      'linkURL' => '',
      'referenceId' => brightcove_generate_reference(),
    );

    $vid = brightcove_upload_video($file->filepath, $meta);

    $_SESSION['video_' . $vid] = $video;

    db_query('DELETE FROM {files} WHERE fid = %d', $file->fid);
    unlink($file->filepath);

    $video = array('vid' => $vid);
    if ($uri = services_resource_uri(array('brightcove', $vid))) {
      $video['uri'] = $uri;
    }
    return $video;
  }
}

function _brightcove_resource_delete($vid) {
  $vid = (double) $vid;
  if ($vid != 0) {
    $bc = brightcove_initialize();
    $result = $bc->delete('video', $vid);
    $deleted = array('deleted' => 1);
  }
  else {
    $deleted = array('deleted' => 0);
  }
  return $deleted;
}